<?php

namespace Drupal\group_computed_field;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\group\Plugin\GroupContentEnablerManagerInterface;

/**
 * Class GroupComputedFieldEntityTypeHelper.
 *
 * Provides a set of tools to get the currently enabled group entities.
 */
class GroupComputedFieldEntityTypeHelper {
  /**
   * Drupal's entity type manager interface.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The Group module's content enabler manager interface.
   *
   * @var \Drupal\group\Plugin\GroupContentEnablerManagerInterface
   */
  protected $groupContentEnabler;

  /**
   * {@inheritDoc}
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   Drupal's entity type manager interface.
   * @param \Drupal\group\Plugin\GroupContentEnablerManagerInterface $group_content_enabler
   *   The Group module's content enabler manager interface.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, GroupContentEnablerManagerInterface $group_content_enabler) {
    $this->entityTypeManager = $entity_type_manager;
    $this->groupContentEnabler = $group_content_enabler;
  }

  /**
   * Gets all installed group content entity ids.
   *
   * @return string[]
   *   An array of content entity ids.
   */
  public function getInstalledGroupContentEntityIds() {
    $installedIds = $this->groupContentEnabler->getInstalled();
    $group_entity_type_ids = [];

    foreach ($installedIds as $installedId) {
      $entity_type_id = $installedId->getEntityTypeId();

      $group_entity_type_ids[] = $entity_type_id;
    }

    return array_unique($group_entity_type_ids);
  }

  /**
   * Gets the related groups for a given entity.
   */
  public function getRelatedGroups($entity) {
    $related_groups = [];

    if ($entity->id() !== NULL && !$entity->isNew()) {
      $group_content_storage = $this->entityTypeManager->getStorage('group_content');
      $group_content_entities = $group_content_storage->loadByEntity($entity);

      foreach ($group_content_entities as $group_content_entity) {
        $related_board = $group_content_entity->getGroup();
        $related_groups[] = $related_board;
      }
    }

    return $related_groups;
  }

}
